#
# spec file for package stow
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stow
Version:        2.3.1
Release:        1.17
Summary:        Manage the installation of software packages from source
License:        GPL-3.0-or-later
Group:          System/Packages
URL:            https://gnu.org/software/stow/
Source:         https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.bz2
Source1:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.bz2.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=stow&download=1#/%name.keyring
Source3:        stow-rpmlintrc
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Output)
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
Requires:       perl >= 5.6.1
BuildArch:      noarch
%{?perl_requires}
%{?libperl_requires}

%description
GNU Stow is a symlink farm manager which takes distinct packages of
software and/or data located in separate directories on the
filesystem, and makes them appear to be installed in the same place.
For example, %{_prefix}/local/bin could contain symlinks to files within
%{_prefix}/local/stow/emacs/bin, %{_prefix}/local/stow/perl/bin etc., and
likewise recursively for any other subdirectories such as .../share,
.../man, and so on.

This is particularly useful for keeping track of system-wide and
per-user installations of software built from source, but can also
facilitate a more controlled approach to management of configuration
files in the user's home directory, especially when coupled with
version control systems.

Stow is implemented as a combination of a Perl script providing a CLI
interface, and a backend Perl module which does most of the work.

%package doc
Summary:        Documentation for GNU Stow
Group:          System/Packages
Requires:       %{name} = %{version}

%description doc
Documentation for GNU Stow %{version} in HTML and PDF format.

%prep
%setup -q

%build
%configure \
    --with-pmdir=%{perl_vendorlib} \
    --docdir=%{_defaultdocdir}/%{name}

%install
%make_install
rm %{buildroot}%{_docdir}/stow/version.texi
rm %{buildroot}%{_docdir}/%{name}/INSTALL.md

%check
%make_build test

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{?ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{?ext_info}

%files
%license COPYING
%doc AUTHORS ChangeLog doc/ChangeLog.OLD README.md NEWS THANKS TODO
%{_bindir}/*
%{_mandir}/man8/stow.*
%{_infodir}/stow*
%dir %{_docdir}/stow
%{perl_vendorlib}/*

%files doc
%{_docdir}/stow/manual-single.html
%{_docdir}/stow/manual-split
%{_docdir}/stow/manual.pdf

%changelog
* Fri Apr  9 2021 suse@adamspiers.org
- A few more minor spec tweaks.  Thanks to Dirk Mueller for some
  of these.
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Some spec clean-up.
* Sun Aug  4 2019 Andreas Stieger <andreas.stieger@gmx.de>
- stow 2.3.1:
  * New --dotfiles option for handling dotfiles
  * Shell-like expansion in .stowrc files
  * chkstow now honours the $STOW_DIR environment variable
  * License changed to GPL 3
* Sun Nov 15 2015 astieger@suse.com
- stow 2.2.2
  * @VERSION@ substitution was set up for the Stow::Util module.
- includes changes from unreleased 2.2.1:
  * various bug fixes
  * Correctly handle the stow/target directories as non-canonical paths
  * Fix stowing of relative links when --no-folding is used.
- verify tarball signature
* Wed Aug  6 2014 aspiers@suse.com
- Rename rpmlintrc as per pkg guideline to %%{name}-rpmlintrc
  (SR #243198)
- Remove old, unused stow.spec.quux
* Thu Sep 12 2013 aspiers@suse.com
- Use %%configure and %%perl_requires macros.
- Don't rm -rf $RPM_BUILD_ROOT.
* Wed Sep 11 2013 aspiers@suse.com
- Run "osc service localrun format_spec_file" on spec file.
* Tue Jan  8 2013 aspiers@suse.com
- split off HTML/PDF docs into -doc subpackage
- fix some rpmlint warnings
* Thu Mar  1 2012 aspiers@suse.com
- improve Description
- fix License field
* Wed Feb 29 2012 aspiers@suse.com
- update to 2.2.0
* Thu Jan 12 2012 Adam Spiers <aspiers@suse.com>
- update to 2.1.3
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Clean up specfile
* Tue May 13 2003 mmj@suse.de
- Remove files we don't package
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 mmj@suse.de
- Only delete info entries when removing last version.
* Fri Feb  7 2003 mmj@suse.de
- Use %%install_info macro
- Cleanup the build root
* Mon Oct 28 2002 mmj@suse.de
- Initial addition, version 1.3.3
